==> azureml_automl_dnn_nlp-1.30.0-py3-none-any.whl: azureml/automl/dnn/nlp/classification/io/write/score_script.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""Score text dataset from model produced by training run."""

import argparse
import logging
import os
import torch

from azureml.automl.dnn.nlp.classification.common.constants import (
    OutputLiterals,
    ScoringLiterals
)
from azureml.automl.dnn.nlp.classification.inference.multilabel_inferencer import MultilabelInferencer
from azureml.automl.dnn.nlp.common import utils
from azureml.core.experiment import Experiment
from azureml.core.run import Run
from azureml.train.automl import constants


_logger = logging.getLogger(__name__)


def _make_arg(arg_name: str) -> str:
    return "--{}".format(arg_name)


def _get_default_device():
    return torch.device("cuda:0" if torch.cuda.is_available() else "cpu")


def _distill_run_from_experiment(run_id, experiment_name):
    """Obtain Run object from runId and experiment name

    :param run_id: azureml run id
    :type run_id: str
    :param experiment_name: name of experiment
    :type experiment_name: str
    :return: Run object
    :rtype: Run
    """
    current_experiment = Run.get_context().experiment
    experiment = current_experiment

    if experiment_name is not None:
        workspace = current_experiment.workspace
        experiment = Experiment(workspace, experiment_name)

    return Run(experiment=experiment, run_id=run_id)


def main():
    """Wrapper method to execute script only when called and not when imported."""
    parser = argparse.ArgumentParser()
    parser.add_argument(_make_arg(ScoringLiterals.RUN_ID),
                        help='run id of the experiment that generated the model')
    parser.add_argument(_make_arg(ScoringLiterals.EXPERIMENT_NAME),
                        help='experiment that ran the run which generated the model')
    parser.add_argument(_make_arg(ScoringLiterals.OUTPUT_FILE),
                        help='path to output file')
    parser.add_argument(_make_arg(ScoringLiterals.INPUT_DATASET_ID),
                        help='input_dataset_id')
    parser.add_argument(_make_arg(ScoringLiterals.LOG_OUTPUT_FILE_INFO),
                        help='log output file debug info', type=bool, default=False)

    args, unknown = parser.parse_known_args()

    task_type = constants.Tasks.TEXT_CLASSIFICATION_MULTILABEL
    utils._set_logging_parameters(task_type, args)

    # TODO JEDI
    # When we expose the package to customers we need to revisit. We should not log any unknown
    # args when the customers send their hp space.
    if unknown:
        _logger.info("Got unknown args, will ignore them: {}".format(unknown))

    device = _get_default_device()

    run_object = _distill_run_from_experiment(args.run_id, args.experiment_name)

    inferencer = MultilabelInferencer(run=run_object,
                                      device=device)

    predicted_df = inferencer.score(input_dataset_id=args.input_dataset_id)

    os.makedirs(OutputLiterals.OUTPUT_DIR, exist_ok=True)
    predictions_path = os.path.join(OutputLiterals.OUTPUT_DIR, "predictions.csv")
    predicted_df.to_csv(predictions_path, index=False)
    _logger.info("Results saved at location: {}".format(predictions_path))

    return


if __name__ == "__main__":
    # Execute only if run as a script
    main()

==> azureml_automl_dnn_nlp-1.31.0-py3-none-any.whl: azureml/automl/dnn/nlp/classification/io/write/score_script.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""Score text dataset from model produced by training run."""

import argparse
import logging
import os
import torch

from azureml.automl.dnn.nlp.classification.common.constants import DatasetLiterals
from azureml.automl.dnn.nlp.classification.inference.multilabel_inferencer import MultilabelInferencer
from azureml.automl.dnn.nlp.common import utils
from azureml.automl.dnn.nlp.common.constants import OutputLiterals, ScoringLiterals
from azureml.core.experiment import Experiment
from azureml.core.run import Run
from azureml.train.automl import constants


_logger = logging.getLogger(__name__)


def _make_arg(arg_name: str) -> str:
    return "--{}".format(arg_name)


def _get_default_device():
    return torch.device("cuda:0" if torch.cuda.is_available() else "cpu")


def _distill_run_from_experiment(run_id, experiment_name):
    """Obtain Run object from runId and experiment name

    :param run_id: azureml run id
    :type run_id: str
    :param experiment_name: name of experiment
    :type experiment_name: str
    :return: Run object
    :rtype: Run
    """
    current_experiment = Run.get_context().experiment
    experiment = current_experiment

    if experiment_name is not None:
        workspace = current_experiment.workspace
        experiment = Experiment(workspace, experiment_name)

    return Run(experiment=experiment, run_id=run_id)


def main():
    """Wrapper method to execute script only when called and not when imported."""
    parser = argparse.ArgumentParser()
    parser.add_argument(_make_arg(ScoringLiterals.RUN_ID),
                        help='run id of the experiment that generated the model')
    parser.add_argument(_make_arg(ScoringLiterals.EXPERIMENT_NAME),
                        help='experiment that ran the run which generated the model')
    parser.add_argument(_make_arg(ScoringLiterals.OUTPUT_FILE),
                        help='path to output file')
    parser.add_argument(_make_arg(ScoringLiterals.INPUT_DATASET_ID),
                        help='input_dataset_id')
    parser.add_argument(_make_arg(ScoringLiterals.LOG_OUTPUT_FILE_INFO),
                        help='log output file debug info', type=bool, default=False)
    parser.add_argument(_make_arg(ScoringLiterals.ENABLE_DATAPOINT_ID_OUTPUT),
                        help='inference output will contain only datapoint ID and predictions',
                        type=bool, default=False)

    args, unknown = parser.parse_known_args()

    task_type = constants.Tasks.TEXT_CLASSIFICATION_MULTILABEL
    utils._set_logging_parameters(task_type, args)

    if unknown:
        _logger.info("Got unknown args, will ignore them.")

    device = _get_default_device()

    run_object = _distill_run_from_experiment(args.run_id, args.experiment_name)

    inferencer = MultilabelInferencer(run=run_object,
                                      device=device)

    predicted_df = inferencer.score(input_dataset_id=args.input_dataset_id)

    if args.enable_datapoint_id_output:
        output_cols = [DatasetLiterals.DATAPOINT_ID, DatasetLiterals.LABEL_COLUMN, DatasetLiterals.LABEL_CONFIDENCE]
        predicted_df = predicted_df[output_cols]

    os.makedirs(OutputLiterals.OUTPUT_DIR, exist_ok=True)
    predictions_path = os.path.join(OutputLiterals.OUTPUT_DIR, "predictions.csv")
    predicted_df.to_csv(predictions_path, index=False)
    _logger.info("Results saved at location: {}".format(predictions_path))

    return


if __name__ == "__main__":
    # Execute only if run as a script
    main()
